#!/bin/ksh
#+############################################################################
# File:        HEP_Xsession.f
# Description: all the functions useful for HEP_Xsession and HEP_startup.default
#-----------------------------------------------------------------------------
# WARNING:     Do not modify this file! 
#              If you want to customise the X environment on this system,
#              please consult the HEPiX System Administrator Document at:
#                 http://wwwcn.cern.ch/hepix/wg/scripts/www/X11/
#-----------------------------------------------------------------------------
# Authors:     L. Cons and A. Taddei (CERN/CN/DCI)
# Contact:     hepix-x11-wg@hepnrc.hep.net
# Version:     @(#)3.2.2 compiled for hp_ux102 on Thu Jul 17 12:25:07 1997
#-############################################################################

#+++############################################################################
#                                                                              #
# basic functions                                                              #
#                                                                              #
#---############################################################################

Info()
{
   echo "Info: $*"
}

Warn()
{
   echo "Warn: $*"
}

Die()
{
   Warn $*
   exit 1
}

Underline2()
{
   # underline with -
   echo $*
   echo "------------------------"
}

Underline1()
{
   # underline with =
   echo $*
   echo "========================="
}

ParseOptions()
{
   #
   # parse (and consume) the arguments in $* and set:
   #  - $debug = 0 or 1 if we're debugging
   #  - $failsafe = 0 or 1 is it's a failsafe session
   #  - $fake = 0 or 1 or 2
   #  - $setup = 0 or 1 if we're seeting up the files only
   #  - $xforward = "" or "login target"
   # stop on the first unknown argument
   #
   debug=0
   failsafe=0
   fake=0
   setup=0
   xforward=""
   while [[ $# -gt 0 ]]; do
     case $1 in
       debug|-debug)       debug=1; shift;;
       failsafe|-failsafe) failsafe=1; shift;;
       fake|-fake)         fake=1; shift;;
       fake1|-fake1)       fake=1; shift;;
       fake2|-fake2)       fake=2; shift;;
       setup|-setup)       setup=1; shift;;
       xforward|-xforward) xforward="$2 $3"; shift 3;;
       *)                  break;;
     esac
   done
}

#+++############################################################################
#                                                                              #
# basic system functions                                                       #
#                                                                              #
#---############################################################################

ShSourceFile()
{
   #+===========================================
   # This function is used to source a Bourne
   # shell script after testing if it is 
   # readable. No error if not readable.
   # 
   # ShSourceFile file
   #-===========================================
   if [[ -r "$1" ]]; then
     Info "  sourcing $1"
     [[ $debug -gt 0 ]] && set -x
     . "$1"
     set -
   fi
}

RunFile()
{
   #+===========================================
   # This function is used to execute a program
   # (shell script or real binary)
   # either in the background or in the
   # foreground. No error if not readable.
   # 
   # RunFile background|foreground file
   #-===========================================
   if [[ -r "$2" ]]; then
     if [[ $fake -gt 0 ]]; then
       Info "  would run $2 in $1"
     elif [[ -x "$2" ]]; then
       # a binary
       Info "  running program $2 in $1"
       if [[ "$1" = "background" ]]; then
	 "$2" &
       else
	 "$2"
       fi
     else
       # a shell script so always in foreground!
       Info "  sourcing script $2"
       [[ $debug -gt 0 ]] && set -x
       . "$2"
       set -
     fi
   fi
}

EnsureDir()
{
   #+===============================================
   # This function ensures the presence of a 
   # directory (does not use -p so it may fail).
   #
   # EnsureDir directory [parent]
   #-=============================================== 
   dir=$1
   parent=$2
   if [[ -n "$parent" ]]; then
     old=`pwd`
     cd $parent
   fi
   if [[ ! -d "$dir" ]]; then
     # mv it if it is a file
     if [[ -r "$dir" ]]; then
       /bin/mv $dir ${dir}_mv
     fi
     /bin/mkdir $dir
   fi
   if [[ -n "$parent" ]]; then
       cd $old
       unset old
   fi
   unset dir parent
}

#+++############################################################################
#                                                                              #
# basic X functions                                                            #
#                                                                              #
#---############################################################################

FatalError()
{
   # popup an error message with xmessage and go in failsafe
   ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xmessage-ack -file "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/message/$1"
   Failsafe
}

UseResFrom()
{
   #+==============================================
   # This function saves the Resources from a 
   # specified file into a target:
   # 
   # UseResFrom target file
   #-==============================================
   if [[ -r "$2" ]]; then
      if [[ $fake -gt 0 ]]; then
         Info "  would use X resources from $2"
      else
	 if [[ -x "$2" ]]; then
	   # the output of the program is used
	   Info "  using X resources from program $2"
	   echo "!" >> $1
	   echo "! X resources from program $2" >> $1
	   echo "!" >> $1
	   $2 >> $1
	 else
	   # the contents of the file is used
	   Info "  using X resources from file $2"
	   echo "!" >> $1
	   echo "! X resources from file $2" >> $1
	   echo "!" >> $1
	   /bin/cat $2 >> $1
	 fi
         # add an extra line if the file is not newline-terminated...
         echo "" >> $1
      fi
   fi
}

Rubout()
{
   #+======================================================
   # This function is used to reset the Rubout sequence to 
   # the xterm program according to what is specified by
   # the user.
   #-======================================================
   export RUBOUT="BackSpace"
   [[ -r "$HOME/.Delete"    ]] && RUBOUT="Delete"
   [[ -r "$HOME/.BackSpace" ]] && RUBOUT="BackSpace"
   [[ $debug -gt 0 ]] && Info "  set RUBOUT=$RUBOUT"
   if [[ "$RUBOUT" = "Delete" ]]; then
     res="XTerm*ttyModes: intr ^C kill ^U susp ^Z erase ^?"
   else
     res="XTerm*ttyModes: intr ^C kill ^U susp ^Z erase ^H"
   fi
   if [[ $fake -gt 0 ]]; then
     Info "  would use X resource: $res" 
   else    
     Info "  using X resource: $res"
     echo "!" >> $1
     echo "! special X resource because RUBOUT=$RUBOUT" >> $1
     echo "!" >> $1
     echo $res >> $1
     echo "" >> $1
   fi
   unset res
}

LoadResources()
{
   #+======================================================
   # This function loads all the resources available at 
   # each level
   #-======================================================
   gen_res="$HOME/.hepix/generated_xresources"
   if [[ $fake -eq 0 ]]; then
     /bin/rm -f $gen_res
     /bin/touch $gen_res
     /bin/cat ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/generated_xresources.head >> $gen_res
     for v in SERVER_HOST VENDOR_STRING VENDOR RELEASE KEYBOARD EXTENSIONS SERVER_TYPE WIDTH HEIGHT SIZE RESOLUTION PLANES COLOR; do
       eval "x=\$HX_$v"
       echo "#define HX_$v $x" >> $gen_res
     done
     echo "" >> $gen_res
     unset x v
   fi
   UseResFrom $gen_res "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_Xresources"
   UseResFrom $gen_res "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/Xresources"
   UseResFrom $gen_res "/etc/hepix/cluster/Xresources"
   UseResFrom $gen_res "/etc/hepix/Xresources"
   UseResFrom $gen_res "$HX_GROUP_DIR/group_Xresources"
   if [[ -r "$HOME/.Xdefaults" ]]; then
     if [[ -r "$HOME/.Xresources" ]]; then
       # both exist
       Warn "  you have both a .Xresources and a .Xdefaults in your home directory,"
       echo "        you should use only .Xresources"
     else
       # only .Xdefaults
       Warn "  you should rename the file .Xdefaults in your home directory"
       echo "        to the standard name: .Xresources"
     fi
     UseResFrom $gen_res "$HOME/.Xdefaults"
   fi
   UseResFrom $gen_res "$HOME/.Xresources"
   Rubout     $gen_res
   UseResFrom $gen_res "$HOME/.hepix/xresources"
   # really load the resources
   if [[ $fake -eq 0 ]]; then
     Info "  loading the X resources from $gen_res"
     /usr/bin/X11/xrdb -load $gen_res
   else
     Info "  would load the X resources from $gen_res"
   fi
   unset gen_res
}

FontPathSetting()
{
   #+=====================================================
   # This function is meant to provide the proper calls
   # to the xset fp+ ... command
   #
   # The HX_FONT_PATH is set after Xinfo and then you look 
   # at the value found in the xprofile files.
   #
   # We now use the program xsetfp that is more flexible
   # than xset
   #-=====================================================
   if [[ -n "$HX_FONT_PATH" ]]; then
     Info "- appending $HX_FONT_PATH to the X font path"
     if [[ "$HX_VENDOR" = "vision" ]]; then
       Warn "cannot modify the font path for the XVision X server"
     elif [[ $fake -gt 0 ]]; then
       Info "  would run '${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsetfp $HX_FONT_PATH'"
     elif [[ $debug -gt 0 ]]; then
       ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsetfp -v $HX_FONT_PATH
     else
       ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsetfp $HX_FONT_PATH
     fi
   fi
   unset HX_FONT_PATH
}

UseMapFrom()
{
   #+==============================================
   # This function saves the key mappings from a 
   # specified file into a target:
   # 
   # UseMapFrom target file
   #-==============================================
   if [[ -r "$2" ]]; then
      if [[ $fake -gt 0 ]]; then
         Info "  would use key mappings from $2"
      else
	 if [[ -x "$2" ]]; then
	   # the output of the program is used
	   Info "  using key mappings from program $2"
	   echo "!" >> $1
	   echo "! key mappings from program $2" >> $1
	   echo "!" >> $1
	   $2 >> $1
	 else
	   # the contents of the file is used
	   Info "  using key mappings from file $2"
	   echo "!" >> $1
	   echo "! key mappings from file $2" >> $1
	   echo "!" >> $1
	   /bin/cat $2 >> $1
	 fi
         # add an extra line if the file is not newline-terminated...
         echo "" >> $1
      fi
   fi
}

KeymapSettings()
{
   #+=====================================================
   # This function merges all the xmodmap settings
   # and finally calls xmodmap
   #-=====================================================
   if [[ -n "$HX_KEYBOARD" ]]; then
     gen_map="$HOME/.hepix/generated_xmodmaprc"
     if [[ $fake -eq 0 ]]; then
       /bin/rm -f $gen_map
       /bin/touch $gen_map
     fi
     UseMapFrom $gen_map "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xkbd.$HX_KEYBOARD"
     UseMapFrom $gen_map "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xkbd.$HX_KEYBOARD"
     UseMapFrom $gen_map "/etc/hepix/cluster/xkbd.$HX_KEYBOARD"
     UseMapFrom $gen_map "/etc/hepix/xkbd.$HX_KEYBOARD"
     UseMapFrom $gen_map "$HX_GROUP_DIR/group_xkbd.$HX_KEYBOARD"
     UseMapFrom $gen_map "$HOME/.hepix/xkbd.$HX_KEYBOARD"
     if [[ -s $gen_map ]]; then
       # there are some keymappings to use
       /bin/rm -f "$gen_map.old"
       /bin/mv $gen_map "$gen_map.old"
       /bin/cat ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/generated_xmodmaprc.head "$gen_map.old" > $gen_map
       /bin/rm -f "$gen_map.old"
       Info "- setting the keymappings for $HX_KEYBOARD from"
       echo "        $gen_map"
       if [[ $fake -gt 0 ]]; then
	 Info "  would run '/usr/bin/X11/xmodmap $gen_map'"
       else
	 Info "  running '/usr/bin/X11/xmodmap $gen_map'"
	 /usr/bin/X11/xmodmap $gen_map
       fi
     else
       # remove it as it is empty
       /bin/rm -f $gen_map
     fi
     unset gen_map
   fi
}

#+++############################################################################
#                                                                              #
# basic HEPiX functions                                                        #
#                                                                              #
#---############################################################################

Failsafe()
{
   #+===========================================
   # This function fails the session into a 
   # failsafe mode. Ususally it provides a single
   # xterm window without any window manager. 
   # Thus the user can look at his configuration
   # and reset anything
   #-===========================================
   Warn "going into failsafe mode now"
   exec /usr/bin/X11/xterm -geometry 80x24+0+0 -ls
   exec xterm -geometry 80x24+0+0 -ls
   exit 1 # just in case...
}

XForwardSession()
{
   #+============================================
   # This function is the front-end to "xforward"
   # the session to a target machine
   # 
   # XForwardSession xlogin-server target
   #
   # In principle an xrsh call should be performed
   # in order to pass the DISPLAY and the MAGIC-
   # COOKIE to the target
   #-============================================
   Info "X forwarding the Xsession from $1 to $2"
   Warn "not yet implemented"
   Failsafe 
}

SetupHepixDir()
{
   #+==========================================
   # This command sets up the user $HOME/.hepix
   # directory and redirects the output.
   #-==========================================

   # setup directories
   EnsureDir "$HOME/.hepix"
   if [[ -d "$HOME/.hepix/fvwm" ]]; then 
     /bin/mv "$HOME/.hepix/fvwm" "$HOME/.hepix/wm"
   else
     EnsureDir "wm" "$HOME/.hepix" 
   fi
   # handle log file
   log="$HOME/.hepix/xsession.log"
   [[ -f "${log}.old" ]] && /bin/rm -f "${log}.old"
   [[ -f "$log"       ]] && /bin/mv "$log" "${log}.old"
   /bin/touch "$log"
   if [[ $? -eq 0 ]]; then
     Info "redirecting the output to $log..."
     exec 1>>$log 2>>$log
   fi
}

#+++############################################################################
#                                                                              #
# PreliminaryTasks                                                             #
#                                                                              #
#---############################################################################

PreliminaryTasks()
{
   #+===============================================
   # 4.1.0 Preliminary tasks to be performed:
   #          - provide a hook for sysadmins to 
   #            specify their own way to handle
   #            the checks (for /etc/passwd, etc.)
   #          - check /etc/nologin
   #          - Enable the security
   #          - goes in failsafe mode if needed
   #          - check the availability of $HOME
   #          - create user log files in $HOME
   #-===============================================

   #+----------------------------------------
   #:To be proposed:
   # Check for specific HEP, site, system, 
   # cluster, group sysadmin tasks which 
   # should be performed here
   #-----------------------------------------
   # SpecificPrelimiaryTasks

   #+----------------------------------------
   # Check for restricted logins
   #-----------------------------------------
   if [[ -r "/etc/nologin" ]]; then
      # we display this with a dialog box
      (echo "Sorry: System under maintenance: No logins";
       echo "";
       /bin/cat /etc/nologin) | ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xmessage-ack -file -
      exit 1
   fi

   #+----------------------------------------
   # Start failsafe if the user asked it
   #-----------------------------------------
   if [[ $failsafe -gt 0 ]]; then
      Failsafe
   fi

   #+----------------------------------------
   # Please be patient...
   #-----------------------------------------
   echo "Starting an X session for ${USER}@${DISPLAY} on `/bin/date`"
   ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xmessage-tmp -file ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/message/welcome &

   #+----------------------------------------
   # Check for the availability of the HOME 
   # directory and setup the user log file
   #-----------------------------------------
   if [[ ! -d "$HOME" ]]; then
     Warn "the home directory ($HOME) is not valid, trying /homeless..." 
     export HOME="/homeless"
     [[ $debug -gt 0 ]] && Info "  set HOME=$HOME"
   fi
   if [[ -d "$HOME" ]]; then
     # we check the quotas
     if [[ -n "`${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/quota-warn -s 500`" ]]; then
       Warn "we are exceeding the quotas"
       FatalError quota
     else
       # can we write to the HOME directory?
       /bin/touch $HOME/a.$$ 2>&1 > /dev/null
       if [[ $? -ne 0 ]]; then
	 Warn "we cannot write to the home directory"
	 FatalError home-write
       else
	 /bin/rm -f $HOME/a.$$ 2>&1 > /dev/null
	 # everything is OK so far
       fi
     fi
   else
     Warn "the home directory ($HOME) is not valid"
     FatalError home-problem
   fi

   #+----------------------------------------
   # Create the user files and redirect IO
   #-----------------------------------------
   SetupHepixDir
   # redirect stdin
   exec 0</dev/null

   #+----------------------------------------
   # print some info for the log
   #-----------------------------------------
   echo "Starting an X session on `/bin/date`"
   if [[ $debug -gt 0 ]]; then
     echo "+ environment at this point is:"
     /bin/printenv | /bin/sort
   else
     echo "  DISPLAY=$DISPLAY HOST=`/bin/hostname`"
   fi
   echo ""
   Underline1 "Running the preliminary tasks"
   Info "- checking for /etc/nologin"
   Info "- checking for failsafe mode"
   Info "- checking the home directory"
   Info "- checking $HOME/.hepix"

   #+----------------------------------------
   # Enable the security
   #-----------------------------------------
   Info "- protecting the X server"
   if [[ $fake -gt 0 ]]; then
     Info "  would run '${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsecure'"
   elif [[ $debug -gt 0 ]]; then
     ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsecure -v
   else
     ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xsecure
   fi

   echo ""
}

#+++############################################################################
#                                                                              #
# ProcessOptions                                                               #
#                                                                              #
#---############################################################################

ProcessOptions()
{
  #+============================================
  # 4.1.1 - This function processes the options
  #         found in the args
  #-============================================
  
  Underline1 "Processing the options"
  if [[ $debug -gt 0 ]]; then
    Info "- debug level $debug option enabled"
  fi
  if [[ $failsafe -gt 0 ]]; then
    # should have been handled in PreliminaryTasks...
    Info "- failsafe session selected"
    Failsafe
  fi
  if [[ $fake -gt 0 ]]; then
    Info "- fake level $fake option enabled"
  fi
  if [[ -n "$xforward" ]]; then
    XForwardSession $xforward
  fi
  echo ""
}

#+++############################################################################
#                                                                              #
# GetInfo                                                                      #
#                                                                              #
#---############################################################################

GetKeyboardInfo()
{
  # get HX_KEYBOARD from the keyboard files using HX_SERVER_HOST
  files=""
  [[ -r "$HOME/.hepix/xkeyboard" ]] && files="$files $HOME/.hepix/xkeyboard"
  [[ -r "$HX_GROUP_DIR/group_xkeyboard" ]] && files="$files $HX_GROUP_DIR/group_xkeyboard"
  [[ -r "/etc/hepix/xkeyboard" ]] && files="$files /etc/hepix/xkeyboard"
  [[ -r "/etc/hepix/cluster/xkeyboard" ]] && files="$files /etc/hepix/cluster/xkeyboard"
  [[ -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xkeyboard" ]] && files="$files ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xkeyboard"
  [[ -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xkeyboard" ]] && files="$files ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xkeyboard"
  if [[ -n "$files" ]]; then
    Info "- trying to set HX_KEYBOARD from the keyboard files:"
    Info "  $files"
    kbd=`/bin/awk -f ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/get_keyboard.awk $files`
    if [[ -n "$kbd" ]]; then
      HX_KEYBOARD=$kbd
      Info "  HX_KEYBOARD is now '$kbd'"
    fi
    unset kbd
  fi
  unset files
}

GetInfo()
{
  #+=================================================
  # 4.1.2 Get the information
  #          - get Terminal context: run xinfo
  #          - get Host context through the HEPiX 
  #            scripts (but the user part)
  #          - get HEP, site, system, cluster, group,
  #            user preferences
  #-==================================================
  Underline1 "Getting the information"

  # init some values expected to be in xprofile
  # HX_GROUP_DIR *must* be overwritten in the site's xprofile
  export HX_VERSION="3.2.2"
  export HX_DESKTOP=""
  export HX_FONT_PATH=""
  export HX_GROUP_DIR="/does-not-exist"
  export HX_KEYBOARD=""
  export HX_LAST_CLIENT=""
  export HX_ROOT_WINDOW=""
  export HX_SOURCEPROFILE=""
  export HX_START_MXCONNS=""
  export HX_STARTUP=""
  export HX_WM=""
  
  #+-----------------------------------------
  # Get X server context, i.e. runs xinfo
  #------------------------------------------
  Info "- getting the X server information"
  [[ $debug -gt 0 ]] && set -x
  eval $(${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/tools/xinfo -k)
  set -
  
  #+-----------------------------------------
  # Get Host context through the HEPiX 
  # scripts (but the user part)
  #------------------------------------------
  if [[ -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_profile" ]]; then
    Info "- getting the host environment"
    export ETC="${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix"
    [[ $debug -gt 0 ]] && Info "  set ETC=$ETC"
    ShSourceFile "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_profile"
    # do we unset HEP_ENV here?
  else
    Warn "cannot get the host environment because the file"
    echo "      ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_profile is not readable"
  fi

  #+-----------------------------------------
  # Get info from the xprofile files
  #------------------------------------------
  Info "- getting the X environment"
  export ENVIRONMENT="X11"
  [[ $debug -gt 0 ]] && Info "  set ENVIRONMENT=$ENVIRONMENT"
  ShSourceFile "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xprofile"
  ShSourceFile "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xprofile"
  ShSourceFile "/etc/hepix/cluster/xprofile"
  ShSourceFile "/etc/hepix/xprofile"
  ShSourceFile "$HX_GROUP_DIR/group_xprofile"
  ShSourceFile "$HOME/.hepix/xprofile"
  
  #+-----------------------------------------
  # Get the keyboard information
  #------------------------------------------
  GetKeyboardInfo
  
  # what do we have now?
  if [[ $debug -gt 0 ]]; then
    echo "+ environment at this point is:"
    /bin/printenv | /bin/sort
  fi
  echo ""
}

#+++############################################################################
#                                                                              #
# ProcessInfo                                                                  #
#                                                                              #
#---############################################################################

ProcessInfo()
{
   #+==============================================
   # 4.1.3 Process the information found in 4.1.2
   #          - check the default values found vs 
   #            the policy and the availability of
   #            the resource
   #          - check the values found vs their 
   #            inter dependencies
   #-==============================================
   Underline1 "Processing the information"
   if [[ $debug -gt 0 ]]; then
     set -x
     eval $(${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/apply_policy -v)
     set -
   else
     eval $(${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/apply_policy)
   fi
   if [[ $debug -eq 0 ]]; then
     Info "  HX_START_MXCONNS=$HX_START_MXCONNS"
     Info "  HX_DESKTOP=$HX_DESKTOP"
     Info "  HX_SOURCEPROFILE=$HX_SOURCEPROFILE"
     Info "  HX_STARTUP=$HX_STARTUP"
     Info "  HX_WM=$HX_WM"
     Info "  HX_LAST_CLIENT=$HX_LAST_CLIENT"
   fi
   echo ""
}

#+++############################################################################
#                                                                              #
# UseInfo                                                                      #
#                                                                              #
#---############################################################################

StartMandatoryClients()
{
   #+======================================================
   # This function launchs all the mandatory clients 
   # specified at each level
   #-======================================================
   RunFile "background" "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xclients.m"
   RunFile "background" "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xclients.m"
   RunFile "background" "/etc/hepix/cluster/xclients.m"
   RunFile "background" "/etc/hepix/xclients.m"
   RunFile "background" "$HX_GROUP_DIR/group_xclients.m"
}

UseInfo()
{
   #+=================================================
   # 4.1.4 Use the information found
   #          - load the resources
   #          - start mandatory clients before the 
   #            the Desktop (CDE, HP-VUE, etc.)
   #-=================================================
   Underline1 "Using the information"

   #+------------------------------------------
   # Load the resources
   #-------------------------------------------
   Info "- loading the X resources"
   LoadResources

   #+------------------------------------------
   # Start mxconns if needed
   #-------------------------------------------
   if [[ -n "$HX_START_MXCONNS" ]]; then
     Info "- starting mxconns"
     if [[ $fake -gt 0 ]]; then
       Info "  would run $HX_START_MXCONNS"
     else
       Info "  $HX_START_MXCONNS"
       export XDISPLAY=`$HX_START_MXCONNS`
       Info "  XDISPLAY is now '$XDISPLAY'"
     fi
   fi
   unset HX_START_MXCONNS

   #+------------------------------------------
   # Start the mandatory clients before the 
   # Desktop (CDE, HP-VUE, etc.) examples of
   # such clients could be 'zephyr', etc.
   #-------------------------------------------
   Info "- starting the mandatory clients"
   StartMandatoryClients
   echo ""
}

#+++############################################################################
#                                                                              #
# RunDesktop                                                                   #
#                                                                              #
#---############################################################################

RunDesktop()
{
   #+=================================================
   # Run the selected desktop
   #-=================================================
   Underline1 "Running the $HX_DESKTOP desktop"

   if [[ "$HX_DESKTOP" != "HEPIX" ]]; then
     if [[ -x "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_desktop.$HX_DESKTOP" ]]; then
       Info "- starting ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_desktop.$HX_DESKTOP"
       echo ""
       if [[ $fake -gt 0 ]]; then
	 exec "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_desktop.$HX_DESKTOP" "-fake$fake"
       else
	 exec "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_desktop.$HX_DESKTOP"
       fi
       exit # just in case
     fi
     Warn "the desktop $HX_DESKTOP is not available, going to failsafe"
     FatalError fatal-error
   fi
   # from here, it's the HEPiX desktop...
   
   #+------------------------------------------
   # Start the 'HEPiX Desktop' specific 
   # mandatory clients 
   #-------------------------------------------
   # StartMandatoryClients 'HEPiX-Desktop'

   #+------------------------------------------
   # Source the user shell profiles if 
   # specified
   #-------------------------------------------
   if [[ "$HX_SOURCEPROFILE" = "yes" ]]; then
     Info "- getting the user shell environment with dump_shell_env"
     if [[ $debug -gt 0 ]]; then
       eval $(${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/dump_shell_env -v DISPLAY USER)
     else
       eval $(${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/dump_shell_env DISPLAY USER)
     fi
   fi
   unset HX_SOURCEPROFILE
   echo ""
}

#+++############################################################################
#                                                                              #
# RunStartup                                                                   #
#                                                                              #
#---############################################################################

StartWindowManager()
{
   #+========================================
   # This function starts the window manager
   # Maybe there will be additional things to 
   # do in the future.
   #
   # Because of ProcessInfo, the value of 
   # HX_WM should be correct.
   #-========================================
   Info "- starting the window manager"
   case $HX_WM in
      local)
         #:In principle we should look at "what does it mean local"
         #:maybe we have to start the ncd windowmanager ?
         Info "  the window manager is a local window manager"
         ;;
      last-client)
         Info "  the window manager will be started as the last client"
	 ;;
      *)
         if [[ $fake -gt 0 ]]; then
	   Info "  would run '$HX_WM &'"
	 else
	   Info "  $HX_WM &"
           # we eval because $HX_WM may contain ``
	   eval $HX_WM &
	 fi
         ;;
   esac
}

StartRootWindow()
{
   #+=======================================
   # This function starts the HX_ROOT_WINDOW
   #-=======================================
   if [[ -n "$HX_ROOT_WINDOW" && "$HX_ROOT_WINDOW" != "none" ]]; then
     Info "- setting the root window"
     if [[ $fake -gt 0 ]]; then
       Info "  would run '$HX_ROOT_WINDOW &'"
     else
       Info "  $HX_ROOT_WINDOW &"
       $HX_ROOT_WINDOW &
     fi
   fi
   unset HX_ROOT_WINDOW
}

StartClients()
{
   #+=======================================
   # This function simply starts the clients 
   # of the session.
   #
   # This function requires no argument.
   # 
   # It goes trhough user, group, cluster,
   # system, site, hep level to find some 
   # clients to start.
   #-=======================================
   Info "- starting the normal X clients"
   if [[ -r "$HOME/.hepix/xclients" ]]; then
     RunFile "background" "$HOME/.hepix/xclients"
   elif [[ -r "$HX_GROUP_DIR/group_xclients" ]]; then
     RunFile "background" "$HX_GROUP_DIR/group_xclients"
   elif [[ -r "/etc/hepix/xclients" ]]; then
     RunFile "background" "/etc/hepix/xclients"
   elif [[ -r "/etc/hepix/cluster/xclients" ]]; then
     RunFile "background" /etc/hepix/cluster/xclients
   elif [[ -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xclients" ]]; then
     RunFile "background" "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/site/xclients" 
   elif [[ -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xclients" ]]; then
     RunFile "background" "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/X11/hep/HEP_xclients"
   fi
}

StartLastClient()
{
   #+=======================================
   # This function simply starts the last
   # client of the session.
   #
   # This function requires no argument.
   #-=======================================
   Info "- starting the last client"
   case $HX_LAST_CLIENT in
     local)
       Info "  the last client specified is 'local' thus you will get an xterm"
       if [[ $fake -gt 0 ]]; then
	 Info "  would start an xterm with title Control Client"
       else
	 echo ""
	 exec /usr/bin/X11/xterm -geometry 50x10-0+150 -T "Control Client" -n "Control Client" -ls
       fi
       ;;
     *)
       if [[ $fake -gt 0 ]]; then
	 Info "  would exec '$HX_LAST_CLIENT'"
       else
	 Info "  $HX_LAST_CLIENT"
	 echo ""
	 # we eval because $HX_LAST_CLIENT may contain ``
	 eval exec $HX_LAST_CLIENT
       fi
       ;;
   esac
   # just in case...
   if [[ $fake -eq 0 ]]; then
     Warn "we could not execute the last client ($HX_LAST_CLIENT)"
     FatalError fatal-error
   else
     echo ""
     Info "Starting an xterm as the last client for fake sessions..."
     exec /usr/bin/X11/xterm
   fi
}

RunStartup()
{
   #+=================================================
   # Run the selected startup
   #-=================================================
   Underline1 "Running the $HX_STARTUP startup"

   if [[ "$HX_STARTUP" != "HEPIX" ]]; then
     if [[ -x "$HX_STARTUP" ]]; then
       Info "- starting $HX_STARTUP"
       # dirty trick to avoid looping: we set DOT_XSESSION
       if [[ "$HX_STARTUP" = "$HOME/.xsession" || "$HX_STARTUP" = "$HOME/.Xsession" ]]; then
         export DOT_XSESSION=$HX_STARTUP
	 [[ $debug -gt 0 ]] && Info "  set DOT_XSESSION=$DOT_XSESSION"
       fi
       echo ""
       # we eval because $HX_STARTUP may contain ``
       if [[ $fake -gt 0 ]]; then
	 eval exec $HX_STARTUP "-fake$fake"
       else
	 eval exec $HX_STARTUP
       fi
       exit # just in case
     fi
     Warn "$HX_STARTUP is not executable, going to failsafe"
     FatalError fatal-error
   fi
   # from here, it's the HEPiX startup...

   FontPathSetting
   KeymapSettings
   StartWindowManager
   StartRootWindow
   StartClients
   StartLastClient
   echo ""
}
