#
#+####################################################################
# File:          AFScheck.pl
# Description:   A perl library for AFSchecking  
# Authors:       A. Miotto (CERN/CN/DCI) - C. Bondila (CERN/CN/DCI)
# Site Contact:  Setup Support <Setup.Support@cern.ch>
# Version:       3.2
# Last Change:   Wed Dec 10 16:41:09 1997
#---------------------------------------------------------------------
# History
#        Alessandro Miotto CN/DCI - 7/3/95
#        Claudia Bondila - checking scripts directory 23/5/95
#        Arnaud Taddei 22/01/1996 - change mkdir($dir,755) --> mkdir($dir,0755)
#-####################################################################


sub AFScheck {
@out = ( README, STDOUT );

$text_end   = "---\n";
$text_fixit = "\nPress <RETURN> to restore the default setup";

$public = "$home/public";
$scripts = "$home/scripts";
$private = "$home/private";
$forward = "$home/.forward";
$pub_forward = "$public/.forward";
$link_forward = "public/.forward";
$pinerc = "$home/.pinerc";
$pine_groupdir = "$ENV{'GROUP_DIR'}/pine";
$pine_groupconf = "$pine_groupdir/addrbook-list";
$rhosts = "$home/.rhosts";
$saveout = "$home/README.AFS-SETUP";

%access = ("r", "- read files contents\n",
	   "w", "- write files\n",
	   "k", "- lock files\n",
	   "l", "- list the files in the directory\n",
	   "i", "- create new files of directories\n",
	   "d", "- delete existing files\n",
	   "a", "- change the access list\n");

open (README, ">$saveout");

#
# check home directory 
#
foreach $o (@out) { print $o "+++ CHECKING HOME DIRECTORY...\n"; }

$home_acl = `fs listacl $home | grep "system:anyuser" | cut -d' ' -f4`;
chop $home_acl;
if ($home_acl ne "l")
{
    @acl = split(//, $home_acl);
    foreach $o (@out) { print $o
"\nThe access control list (ACL) for your home directory is set in such
a way that any system in the world can:\n"; }

    while ($#acl >= 0)
    {
	$a = shift (@acl);
	foreach $o (@out) { print $o $access {$a}; }
    }
    foreach $o (@out) { print $o
"\nThis poses severe security problem since some files in the home 
directory give access to mechanisms for finding your AFS password, thus 
giving access to all systems where you have an AFS account.
The default ACL for the home directory should be to list files only,
and all files you want to give access to should be put in public
subdirectories.\n"; }

    if (! $opt_n)
    { 
	print $text_fixit;
	<STDIN>;
        `fs setacl $home system:anyuser l`;
	foreach $o (@out) 
	{
	    print $o
"\nNow setting the home directory ACL to \"l\" for system:anyuser\n";
	}
    }
}
foreach $o (@out) { print $o $text_end; }

#
# check public directory 
#
foreach $o (@out) { print $o "+++ CHECKING PUBLIC DIRECTORY...\n"; }
if (! -d $public )
{
    foreach $o (@out) { print $o
"\nThere should be a \'public\' directory in your home directory
setup in order to be visible by everybody, in which you can store files 
of public domain. 
All subdirectories that you will create from \'public\' will be 
accessed by everybody by default. You do not have a \'public\' directory.\n"; }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        mkdir($public,0755); 
        `fs setacl $public system:anyuser rl`;
	foreach $o (@out)
	{
	    print $o
"\nNow creating the public directory with \"rl\" access for system:anyuser\n"; 
	}
    }
}
else
{
    $public_acl = `fs listacl $public | grep "system:anyuser" | cut -d' ' -f4`;
    chop $public_acl;
    if ($public_acl ne "rl")
    {
	@acl = split(//, $public_acl);
	foreach $o (@out) { print $o
"There is a \'public\' directory in your home directory which should
be setup in order to be visible by everybody and where you can store files 
of public domain. 
Also, all subdirectories that you will create from \'public\' can be
accessed by everybody by default. The ACL of \'public\' is now setup to be:\n";
			}
        while ($#acl >= 0)
	{
	    $a = shift (@acl);
	    foreach $o (@out) { print $o $access {$a}; }
	}
	foreach $o (@out) { print $o "which is not correct.\n"; }

	if (! $opt_n)
	{ 
	    print $text_fixit;
	    <STDIN>;
            `fs setacl $public system:anyuser rl`;
	    foreach $o (@out)
	    {
		print $o
"\nNow setting the ACL of the public directory to \"rl\" for system:anyuser\n";
	    }
        }
        
     }
     chop ($ll = `ls -l $home | grep public | cut -c 1-10`);
     if ($ll ne "drwxr-xr-x") {
        foreach $o (@out) { print $o
"\nThe Unix file permissions for your \'public\' directory are not correct set:
$ll\t$public\n";
        }
        if (! $opt_n) {
           print $text_fixit;
           <STDIN>;
           $cannot = chmod(0755, $public);
           die "$0: could not chmod $public\n" if !$cannot;

           foreach $o (@out)
           {
              print $o
"\nNow setting the Unix file permissions of the public directory to \"drwxr-xr-x\"\n";

           }

           $cannot = chmod(0755, $public);
           warn "$0: could not chmod $public\n" if !$cannot;
        }
     }
}
foreach $o (@out) { print $o $text_end; }

#
# check scripts directory 
#
foreach $o (@out) { print $o "+++ CHECKING SCRIPTS DIRECTORY...\n"; }
if (! -d $scripts )
{
    foreach $o (@out) { print $o
"\nThere should be a \'scripts\' directory in your home directory
setup in order to be visible by everybody, in which you can store 
system independent executables.
All subdirectories that you will create from \'scripts\' will be 
accessed by everybody by default. You do not have a \'scripts\' directory.\n"; }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        mkdir($scripts,0755); 
        `fs setacl $scripts system:anyuser rl`;
	foreach $o (@out)
	{
	    print $o
"\nNow creating the scripts directory with \"rl\" access for system:anyuser\n"; 
	}
    }
}
else
{
    $scripts_acl = `fs listacl $scripts | grep "system:anyuser" | cut -d' ' -f4`;
    chop $scripts_acl;
    if ($scripts_acl ne "rl")
    {
	@acl = split(//, $scripts_acl);
	foreach $o (@out) { print $o
"There is a \'scripts\' directory in your home directory which should
be setup in order to be visible by everybody and where you can store
system independent executables.
Also, all subdirectories that you will create from \'scripts\' can be
accessed by everybody by default. The ACL of \'scripts\' is now setup to be:\n";
			}
        while ($#acl >= 0)
	{
	    $a = shift (@acl);
	    foreach $o (@out) { print $o $access {$a}; }
	}
	foreach $o (@out) { print $o "which is not correct.\n"; }

	if (! $opt_n)
	{ 
	    print $text_fixit;
	    <STDIN>;
            `fs setacl $scripts system:anyuser rl`;
	    foreach $o (@out)
	    {
		print $o
"\nNow setting the ACL of the scripts directory to \"rl\" for system:anyuser\n";
	    }
        }
     }
}
foreach $o (@out) { print $o $text_end; }

#
# check private directory 
#
foreach $o (@out) { print $o "+++ CHECKING PRIVATE DIRECTORY...\n"; }
if (! -d $private )
{
    foreach $o (@out) { print $o
"\nThere should be a \'private\' directory in your home directory
in which you can store files that nobody can access.
All subdirectories that you will create from \'private\' will also have 
the same access restrictions. You do not have a \'private\' directory.\n"; }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        mkdir($private,0750); 
        `fs setacl $private system:anyuser none`;
	foreach $o (@out)
	{
	    print $o "\nNow creating the private directory.\n"; 
	}
    }
}
else
{
    $private_acl = `fs listacl $private | grep "system:anyuser" | cut -d' ' -f4`;
    chop $private_acl;
    if ($private_acl ne "")
    {
	@acl = split(//, $private_acl);
	foreach $o (@out) { print $o
"There is a \'private\' directory in your home directory which should
be setup in order to store files that nobody can access. 
All subdirectories that you will create from \'private\' will also have
the same access restrictions. The ACL of \'private\' is now setup to be:\n";
			}

        while ($#acl >= 0)
	{
	    $a = shift (@acl);
	    foreach $o (@out) { print $o $access {$a}; }
	}
	foreach $o (@out) { print $o "which is not correct.\n"; }

	if (! $opt_n)
	{ 
	    print $text_fixit;
	    <STDIN>;
            `fs setacl $private system:anyuser none`;
	    foreach $o (@out)
	    {
		print $o
"\nNow setting the ACL of the private directory to none for system:anyuser\n";
	    }
	}
    }
}
foreach $o (@out) { print $o $text_end; }

#
# check .forward to be a link
#
foreach $o (@out) { print $o "+++ CHECKING FORWARD...\n"; }
if (! -l "$forward" || readlink ($forward) ne "$link_forward")
{
    foreach $o (@out)
    {
	print $o
"\nThere should be in your home directory a \'.forward\' file, which is a
link to \'public/.forward\'. 
\(\'.forward\' is used by sendmail to redirect mail messages received on 
the local machine and it must be readable by it, and this is not possible 
if it is stored in your home directory as a normal file. Files in the
\'public\' directory are readable by everybody.\)
You do not have \'.forward\', or it exist but it is not setup correctly.\n"; 
    }

    if (! $opt_n)
    {
        print $text_fixit;
        <STDIN>;
        `uco -f`;
	open (FW, "$forward");
	$address = <FW>;
	close FW;
	foreach $o (@out) { print $o "\nSetting \'.forward\' to $address\n"; }
	$i = 1;
	if (-f "$forward.$i")
	{
	    while (-f "$forward.".($i+1)) { $i++; }
	    open (FW, "$forward.$i");
	    $address = <FW>;
	    close FW;
	    print "You had previously a forward to:\n $address\n";
	    print "Do you want to restore it? (y/n)[n] ";
	    chop ($answer = <STDIN>);
	    if ($answer eq "y")
	    {
		rename ("$forward.$i", "$pub_forward");
		foreach $o (@out)
		{
		    print $o 
"Restoring previous \`.forward\'. to $address"; 
		}
	    }
	}
    }
}
elsif (! -f "$pub_forward")
{
    foreach $o (@out)
    {
	print $o
"\nYou do not have setup a forward for your mail: this might result in
receiving mail in local mailboxes on several different machines where you 
have an AFS account, if these machines are not setup correctly.\n";
    }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        `uco -f`;
	foreach $o (@out)
	{
	    print $o "\nSetting mail forward.\n"; 
	}
    }
}
foreach $o (@out) { print $o $text_end; }

#
# check .rhosts
#
foreach $o (@out) { print $o "+++ CHECKING RHOSTS...\n"; }
if (! -f "$rhosts")
{
    foreach $o (@out)
    {
	print $o
"\nIn order to be able to login without being prompted for your password
from any machine where you have an AFS account, you need a file called
\'.rhosts\' in your home directory setting up the necessary authorization.
This file does not exist in your home directory.\n";
    }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        `uco -R`;
	foreach $o (@out)
	{
	    print $o "\nCreating \'.rhosts\' file.\n"; 
	}
    }
}
foreach $o (@out) { print $o $text_end; }

#
# check shell files
#
foreach $o (@out) { print $o "+++ CHECKING SHELL CONFIGURATION FILES...\n"; }
foreach $o (@out)
{
    print $o
"\nThe HEPiX environment is installed in some machines in non-enforced mode,
i.e. you need to source explicitely the HEPiX configuration files in order
to have your environment set properly. This is presently true for CORE 
machines.
A default set of files can be created, but you will have to manually edit 
them in order to reinsert any modification you added. Original files are 
saved by appending the suffix .#, where # is an incrementing version 
number.\n"; 
}

if (! $opt_n)
{
    print 
"\nDo you want to create a default set of shell configuration files? (y/n)[n] ";
    chop ($answer = <STDIN>);
    if ($answer eq "y")
    {
	`uco -p`;
    }
}
foreach $o (@out) { print $o $text_end; }

#
# check .pinerc
#
foreach $o (@out) { print $o "+++ CHECKING PINE CONFIGURATION FILE...\n"; }
if (-f "$pinerc")
{
    if (-f "$pine_groupconf" && `grep -c \"last-version-used=3.91\" $pinerc`)
    {
	foreach $o (@out)
	{
	    print $o
"\nYou are already a \'pine\' user and there is a configuration file in
your home directory, but the group addressbook customization might not 
be set yet.\n";
	}

	if (! $opt_n)
	{
	    print "\nDo you want to replace group customization? (y/n)[n] ";
	    chop ($answer = <STDIN>);
	    if ($answer eq "y")
	    {
		$i = 1;
		if (-f "$pinerc.$i")
		{
		    while (-f "$pinerc.".($i+1)) { $i++; }
		}
		rename ("$pinerc", "$pinerc.$i");
		`pine -pinerc "$pinerc.tmp"`;
		open (RCIN, "$pinerc.tmp");
		open (RCOUT, ">$pinerc");
		open (RCCONF, "$pine_groupconf");
		$_echo = 1;
		while (<RCIN>)
		{
		    if (/global-address-book=/)
		    {
			$_echo = 0;
			$_gab = 1;
		    }
		    elsif (/List of file or path names for personal addressbook/)
		    {
			$_echo = 1;
		    }
		    
		    if ($_gab)
		    {
			$_gab = 0;
			print RCOUT "global-address-book=";
			$nextline = "";
			while (<RCCONF>)
			{
			    chop $_;
			    print RCOUT $nextline, $pine_groupdir, "/", $_;
			    $nextline = ",\n\t";
			}
			print RCOUT "\n\n";
		    }
		    if ($_echo)
		    {
			print RCOUT;
		    }
		}
		close RCIN;
		close RCOUT;
		close RCCONF;
		unlink ("$pinerc.tmp");
		
		foreach $o (@out)
		{
		    print $o "\nResetting global addressbook list.\n"; 
		}
	    }
	}
    }
}
else
{
    foreach $o (@out)
    {
	print $o
"\n\'pine\' is a screen-oriented mail-handling program, and is the recommended
mail agent in an AFS environment. You have never used \'pine\' before, since 
its configuration file does not exist in your directory. 
A default configuration file will now be copied to your home directory.\n";
    }

    if (! $opt_n)
    {
	print $text_fixit;
	<STDIN>;
        `uco -m`;
	foreach $o (@out)
	{
	    print $o "\nCreating \'pine\' configuration file.\n"; 
	}
    }
}
foreach $o (@out) { print $o $text_end; }

#
# final comment
#
foreach $o (@out)
{
    print $o 
"\nThe text appearing on the screen was saved in the file 
\'README.AFS-SETUP\' in your home directory.
\nFor additional information about restoring the default environment
you can also look at the \'uco\' command manual page.\n";
}
}
1;
