#+############################################################################
# File:        HEP_csh.cshrc
# Description: This is the HEP Level C shell environment part.
#-----------------------------------------------------------------------------
# Authors:     A. Taddei (CERN/IT/DIS) - DESY/DUX
# Contact:     hepix-scripts-wg@hepnrc.hep.net
# Version:     3.2 compiled for sun4x_55 on Wed Dec 10 16:41:36 1997
#-############################################################################

if ( ! $?hep_env_csh ) then #-hep_env_csh
   set hep_env_csh = ( "hep_env_csh" )	#-hep_env_csh

   if ( ! $?USER ) then
      if ( $?LOGNAME ) then
         setenv USER $LOGNAME
      else
         setenv USER `/usr/ucb/whoami`
      endif
   endif
   if ( ! $?LOGNAME ) then
      setenv LOGNAME $USER
   endif

   #+------------------------------------------------------+
   # CHECK FOR LOGIN PERMISSION                            |
   #-------------------------------------------------------+
   if ( -f /etc/nologin &&  $USER != root  ) then  
      echo "Sorry:System under maintenance:No logins"
      /bin/cat /etc/nologin
      /bin/sleep 5
      exec "echo"
      exit
   endif

   setenv GROUP `${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/tools/GroupName`


   #+------------------------------------------------------+
   # HEP_ENV                                               |
   #-------------------------------------------------------+
   if ( ! $?HEP_ENV )  then

      #+---------------------------------------------------+
      # BASIC SHELL ENVIRONMENT I                          |
      #----------------------------------------------------+

      # Set the umask so that newly created files and directories will be 
      # readable by others, but writable only by the user.
      umask 0022

      set path=( /sys5.3/bin /usr/apollo/bin /bin /usr/bin /etc /usr/bsd /usr/ucb )

      set user=$USER
      if ( -r "${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/site/sys.conf.csh" ) then
         source ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/site/sys.conf.csh
      else
         set USERPATH="`echo ${path}` /usr/bin/X11 /usr/local/bin"
         set ROOTPATH="`echo ${path}` /usr/bin/X11"
	 setenv BINTYPE "$OS"
	 setenv SYSTYPE sysV
	 setenv MANPATH "/usr/man:/usr/local/man"
         /bin/tty -s
	 if ( $status == 0 )     then
            echo " Warning !  Missing ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/site/sys.conf "
	 endif
      endif

      setenv HOST `/bin/hostname |/bin/sed "s/\..*//"`

      if ( ! -d "$HOME" && -d /homeless ) then
	 setenv HOME /homeless
	 set home=$HOME
	 cd $HOME
      endif
      set USERPATH=`echo ${USERPATH} | /bin/tr ":" " "`
      set ROOTPATH=`echo ${ROOTPATH} | /bin/tr ":" " "`
      if ( $USER == "root" ) then
	 set path=( ${ROOTPATH} )
      else 
         set path=( ${USERPATH} )
      endif

      unset USERPATH
      unset ROOTPATH
      unset X11BIN
      unsetenv USERPATH
      unsetenv ROOTPATH
      unsetenv X11BIN


      #### to manage the ksh and bash
      setenv ENV ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_zshenv

      #+------------------------------------------------------+
      # LOCAL ADAPT                                           |
      #-------------------------------------------------------+
      if ( -r ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/site/env.csh ) then
         source ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/site/env.csh
      endif
      setenv SAVEPATH "$PATH"

      #+------------------------------------------------------+
      # FINISH HEP_ENV                                        |
      #-------------------------------------------------------+
      if ($?SHELL) then
        setenv HEP_ENV "$SHELL"
      else
        setenv HEP_ENV "UNKNOWN"
      endif

   else
      # We used to check GROUP
   endif # setup HEP_ENV


   # interactiv shell
   source ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_aliases.csh

   /bin/tty -s
   if ( $status == 0 ) then
      if ( ! $?ENVIRONMENT ) then
         setenv ENVIRONMENT INTERACTIVE
      else
         if ( $ENVIRONMENT != "DMLOGIN" ) then
            setenv ENVIRONMENT INTERACTIVE
         endif
      endif

      if (  $?tcsh   ) then
         set prompt='%S[%m]%s %~ %# '
      else
         set whoami=`/usr/ucb/whoami`
         if ( $whoami == "root" ) then
            alias setprompt 'set prompt="${HOST}:${cwd} # "'
         else
            alias setprompt 'set prompt="${HOST}:${cwd} > "'
         endif
         setprompt
         alias cd 'chdir \!* && setprompt'
         unset whoami
      endif


      # to overwrite the restricted path after su
      if ( $?SAVEPATH ) then
         set path=(`echo $SAVEPATH | /bin/tr ":" " "`)
      endif


      if ( $?tcsh && -r ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_tcshrc ) then
         source ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_tcshrc
      else
         if ( -r ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_cshrc.rc ) then
            source ${GROUP_DIR}/${STAR_SYS}/usr.local/lib/hepix/shells/hep/HEP_cshrc.rc
         endif
      endif 

      # Make sure csh.login will be sourced on IRIX
      if ( ! $?SHLVL ) then
         setenv SHLVL 1
      endif
   else
       if ( ! $?ENVIRONMENT ) then
         setenv ENVIRONMENT BATCH
       endif
   endif 

endif #-hep_env_csh

